<template>
  <div class="mod-config">
    <ttable
      :table="table"
      @handleSelectionChange="handleSelectionChange"
      :uploadInfo="uploadInfo"
      :prelang="prelang"
      :options="options"
      :ajaxFun="ajaxFun"
      :paramArr="type"
      :paramObj="paramObj"
      ref="customerOrderTable"
    >
      <template #toolbar> </template>
    </ttable>
  </div>
</template>

<script>
import { mapGetters } from 'vuex'
import ttable from '@/views/common/ztt-table.vue'
import {
  delCustomerOrder,
  fetchListCustomerOrder,
  markPlanned
} from '../../../api/plan/customerorder'

export default {
  props: {
    paramObj: {
      type: Object,
      default: () => {
        return {}
      }
    }
  },
  data() {
    return {
      stateTagArr: [
        {
          label: '标记待计划',
          command: 'PLAN',
          disabled: false,
          permitArr: ['02planing', '04complete', '03planed']
        },
        {
          label: '标记计划中',
          command: 'PLANING',
          disabled: false,
          permitArr: ['01plan', '04complete', '03planed']
        },
        {
          label: '标记已计划',
          command: 'PLANED',
          disabled: false,
          permitArr: ['01plan', '02planing', '04complete']
        },
        {
          label: '标记已完成',
          command: 'COMPLETE',
          disabled: false,
          permitArr: ['02planing', '01plan', '03planed']
        }
      ],
      ajaxFun: fetchListCustomerOrder,
      type: [1],
      mpsRequirementsVisible: false,
      currentRow: null,
      multipleSelection: [],
      isShowQuery: false,
      uploadInfo: {
        // 是否展示上传EXCEL以及对应的url
        isShow: false,
        url: ''
      },
      prelang: 'operation',
      options: {
        height: 300, // 默认高度-为了表头固定
        stripe: true, // 是否为斑马纹 table
        highlightCurrentRow: false, // 是否要高亮当前行
        border: true, // 是否有纵向边框
        lazy: false, // 是否需要懒加载
        fit: true, // 列的宽度是否自撑开
        multiSelect: true, //
        seqNo: true,
        isRefresh: true, // 是否显示刷新按钮
        isSearch: false, // 高级查询按钮
        defaultOrderBy: { column: 'createTime', direction: 'desc' }
      },
      table: {
        total: 0,
        currentPage: 1,
        pageSize: 20,
        data: [],
        // 标题
        column: [
          {
            minWidth: '100',
            width: '100px',
            prop: 'customerOrderNo',
            label: '客户订单号',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            minWidth: '120',
            prop: 'customerNo',
            label: '客户编号',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            minWidth: '120',
            prop: 'customerName',
            label: '客户名称',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            minWidth: '120',
            prop: 'coState',
            label: '客户订单状态',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'select',
            formatter: this.getCustomerCoState,
            optList: () => {
              return this.coStateList
            }
          },
          {
            minWidth: '120',
            prop: 'coLineNo',
            label: '行号',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            minWidth: '120',
            width: '100px',
            prop: 'partNo',
            label: '零件号',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            minWidth: '120',
            width: '100px',
            prop: 'partName',
            label: '零件名称',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            minWidth: '120',
            prop: 'buyQtyDue',
            label: '销售数量',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            minWidth: '140',
            prop: 'requireNumber',
            label: '已下发数量',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            minWidth: '80',
            prop: 'unit',
            label: '零件单位',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            minWidth: '140',
            width: '120',
            prop: 'wantedDeliveryDate',
            label: '期望交货时间',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'datetimerange',
            formatter: this.formatDutyDate
          },
          {
            minWidth: '200',
            width: '120',
            prop: 'plannedDeliveryDate',
            label: '计划交货时间',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'datetimerange',
            formatter: this.formatDutyDate
          },
          {
            minWidth: '200',
            width: '120',
            prop: 'createTime',
            label: '创建时间',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'datetimerange',
            formatter: this.formatDutyDate
          }
        ],
        toolbar: [],
        operator: [],
        operatorConfig: {
          fixed: 'right',
          label: '操作',
          width: 200,
          minWidth: 100
        }
      },
      addOrUpdateVisible: false,
      coStateList: [
        {
          value: '01plan',
          label: '待计划'
        },
        {
          value: '03planed',
          label: '已计划'
        },
        {
          value: '02planing',
          label: '计划中'
        },
        {
          value: '04complete',
          label: '已完成'
        }
      ]
    }
  },
  components: {
    ttable
  },
  computed: {
    ...mapGetters(['permissions'])
  },
  watch: {
    coState: {
      handler(newValue, oldValue) {
        if (newValue) {
          this.getData()
        }
      },
      immediate: true
    }
  },
  methods: {
    getData() {
      this.$refs.customerOrderTable.getDataList()
    },
    // 获取数据列表去除已完成状态的
    handleDataList(command) {
      this.type = [command]
      this.$nextTick(() => {
        this.getData()
      })
    },
    formatDutyDate(row, column, cellValue) {
      if (cellValue) {
        const dutyDateList = /\d{4}-\d{1,2}-\d{1,2}/g.exec(cellValue)
        if (dutyDateList && dutyDateList.length > 0) {
          return dutyDateList[0]
        }
      }
      return ''
    },
    // 同步ERP订单
    syncErpOrder() {
      this.$message.error('正在开发中')
    },
    // 删除
    deleteHandle(row) {
      if (row.sourceId === 'GSM') {
        this.$message.error('当前数据是推送数据不可删除')
        return
      }
      this.$confirm('是否确认删除客户订单号为' + row.customerOrderNo + '提示', {
        confirmButtonText: '确定',
        cancelButtonText: '取消',
        closeOnClickModal: false,
        type: 'warning'
      })
        .then(() => {
          return delCustomerOrder(row.id)
        })
        .then((data) => {
          this.$message.success('删除成功')
          this.getData()
        })
    },
    // table自带事件
    handleSelectionChange(val) {
      // 根据状态，禁用表头按钮
      // 筛选出选中记录的状态
      var stateArr = val.map(function(value, index) {
        return value.coState
      })
      // 选中状态数组元素去重
      var uniqueStateArr = []
      for (var i = 0; i < stateArr.length; i++) {
        if (uniqueStateArr.indexOf(stateArr[i]) == -1) {
          uniqueStateArr.push(stateArr[i])
        }
      }
      // 循环自定义按钮，判断每个按钮的permitArr是否完全包含选中状态，若完全包含，则按钮亮，否则按钮灰
      for (var i = 0; i < this.stateTagArr.length; i++) {
        if (
          uniqueStateArr.every((val) =>
            this.stateTagArr[i].permitArr.length <= 0
              ? true
              : this.stateTagArr[i].permitArr.includes(val)
          )
        ) {
          this.stateTagArr[i].disabled = false
        } else {
          this.stateTagArr[i].disabled = true
        }
      }
      this.multipleSelection = val
    },
    getCustomerCoState(row, column, cellValue) {
      this.coStateList.forEach((obj) => {
        if (obj.value === cellValue) {
          cellValue = obj.label
        }
      })
      return cellValue
    },
    // 状态改变
    handleCommand(event) {
      var eventName
      if (event == 'PLAN') {
        eventName = '待计划'
      } else if (event == 'PLANED') {
        eventName = '已计划'
      } else if (event == 'PLANING') {
        eventName = '计划中'
      } else {
        eventName = '已完成'
      }
      if (this.multipleSelection.length > 0) {
        markPlanned(
          this.multipleSelection.map((item) => {
            return item.id
          }),
          event
        ).then((response) => {
          var data = response.data
          if (data.code == 0) {
            this.$message.success(eventName + '修改成功')
            this.getData()
          } else {
            this.$message.error(eventName + '修改失败')
          }
        })
      } else {
        this.$message.error('请选择' + eventName + '的对象')
      }
    },
    // 创建主计划需求
    createMpsRequirements() {
      if (this.multipleSelection && this.multipleSelection.length > 0) {
        // 1.根据状态判断是否可以继续创建主计划需求
        this.mpsRequirementsVisible = true
        this.$nextTick(() => {
          this.$refs.mpsRequirements.init(this.multipleSelection)
        })
      } else {
        this.$message.error('请选择客户订单')
      }
    }
  }
}
</script>
